============
parselglossy
============


.. image:: https://img.shields.io/pypi/v/parselglossy.svg
        :target: https://pypi.python.org/pypi/parselglossy

.. image:: https://github.com/dev-cafe/parselglossy/workflows/Test%20parselglossy/badge.svg?branch=master
        :target: https://github.com/dev-cafe/parselglossy/actions?query=workflow%3A%22Test+parselglossy%22+branch%3Amaster
        :alt: CI build status
        
.. image:: https://codecov.io/gh/dev-cafe/parselglossy/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/dev-cafe/parselglossy

.. image:: https://readthedocs.org/projects/parselglossy/badge/?version=latest
        :target: https://parselglossy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



.. epigraph::

   "What d'you mean? You were there – you heard me —"

   "I heard you speaking Parseltongue," said Ron. "Snake language. You could have been saying anything – no wonder Justin panicked, you sounded like you were egging the snake on or something – it was creepy, you know —"

   -- J. K. Rowling **Harry Potter and the Chamber of Secrets**

   [...] I speak with tongues more than you all;

   -- **1 Corinthians** 14:18

   Parse it on!

   -- Bobson Dugnutt, **Private communication**


Generic input parsing library, speaking in tongues

.. image:: https://github.com/dev-cafe/parselglossy/raw/master/docs/gfx/parse.jpg
     :alt: Parse all the inputs!

* Free software: MIT license
* Documentation: https://parselglossy.readthedocs.io.


Requirements
------------

* Python 3.6 or later.


Features
--------

* TODO


Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
